==> fcrepo-kernel-api-4.6.1-sources.jar: org/fcrepo/kernel/api/RdfCollectors.java <==
/*
 * Licensed to DuraSpace under one or more contributor license agreements.
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership.
 *
 * DuraSpace licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.fcrepo.kernel.api;

import java.util.stream.Collector;

import com.hp.hpl.jena.rdf.model.ModelFactory;
import com.hp.hpl.jena.graph.Triple;
import com.hp.hpl.jena.rdf.model.Model;

/**
 * A class of Collectors for use with RdfStreams
 * @author acoburn
 * @since Dec 4, 2015
 */
public class RdfCollectors {

    /**
     * @return a Collector for use with aggregating an RdfStream into a Model.
     */
    public static Collector<Triple, ?, Model> toModel() {
        return Collector.of(ModelFactory::createDefaultModel,
            (m, t) -> m.add(m.asStatement(t)),
            (left, right) -> { left.add(right); return left; },
            Collector.Characteristics.UNORDERED);
    }

    private RdfCollectors() {
        // prevent instantiation
    }
}

==> fcrepo-kernel-api-4.7.5-sources.jar: org/fcrepo/kernel/api/RdfCollectors.java <==
/*
 * Licensed to DuraSpace under one or more contributor license agreements.
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership.
 *
 * DuraSpace licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.fcrepo.kernel.api;

import java.util.stream.Collector;

import org.apache.jena.rdf.model.ModelFactory;
import org.apache.jena.graph.Triple;
import org.apache.jena.rdf.model.Model;

/**
 * A class of Collectors for use with RdfStreams
 * @author acoburn
 * @since Dec 4, 2015
 */
public class RdfCollectors {

    /**
     * @return a Collector for use with aggregating an RdfStream into a Model.
     */
    public static Collector<Triple, ?, Model> toModel() {
        return Collector.of(ModelFactory::createDefaultModel,
            (m, t) -> m.add(m.asStatement(t)),
            (left, right) -> { left.add(right); return left; },
            Collector.Characteristics.UNORDERED);
    }

    private RdfCollectors() {
        // prevent instantiation
    }
}
